Module config
infraqueue_
lib
0.1.1
Module config
Module Items
Functions
In crate infraqueue_
lib
infraqueue_lib
Module
config
Functions

env_f64
Read an environment variable as f64 with a default fallback. Returns
default
if the var is missing or cannot be parsed.
env_u32
Read an environment variable as u32 with a default fallback. Returns
default
if the var is missing or cannot be parsed.
env_u64
Read an environment variable as u64 with a default fallback. Returns
default
if the var is missing or cannot be parsed.
env_
var_
or_
file
Read a configuration value from either a direct environment variable
NAME
or from a file path specified via
NAME_FILE
. If both are set,
NAME
takes precedence. Returns
Some(value)
if found, otherwise
None
.
env_
var_
or_
file_
required
Same as
env_var_or_file
, but returns an error message when not found.